[nautilus-actions/file-manager-actions] NAIOption and NAIOptionsList interfaces are renamed to FMAIOption and FMAIOptionsList
- From: Pierre Wieser <pwieser src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [nautilus-actions/file-manager-actions] NAIOption and NAIOptionsList interfaces are renamed to FMAIOption and FMAIOptionsList
- Date: Tue, 8 Sep 2015 10:28:10 +0000 (UTC)
commit 8d20572b78915afebb803d7540e64920a8a678cf
Author: Pierre Wieser <pwieser trychlos org>
Date: Tue Sep 8 11:44:23 2015 +0200
NAIOption and NAIOptionsList interfaces are renamed to FMAIOption and FMAIOptionsList
src/core/Makefile.am | 8 +-
src/core/fma-export-format.c | 32 ++--
src/core/fma-exporter.c | 6 +-
src/core/fma-exporter.h | 4 +-
src/core/fma-import-mode.c | 32 ++--
src/core/fma-importer-ask.c | 26 +-
src/core/fma-importer.c | 10 +-
src/core/fma-importer.h | 4 +-
src/core/{na-ioption.c => fma-ioption.c} | 98 ++++----
src/core/{na-ioption.h => fma-ioption.h} | 74 +++---
.../{na-ioptions-list.c => fma-ioptions-list.c} | 248 ++++++++++----------
.../{na-ioptions-list.h => fma-ioptions-list.h} | 96 ++++----
src/nact/nact-assistant-export.c | 42 ++--
src/nact/nact-assistant-import.c | 44 ++--
src/nact/nact-export-ask.c | 32 ++--
src/nact/nact-preferences-editor.c | 54 +++---
src/utils/nautilus-actions-print.c | 2 +-
17 files changed, 406 insertions(+), 406 deletions(-)
---
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 838c429..2512fb4 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -92,10 +92,10 @@ libna_core_la_SOURCES = \
fma-importer-ask.h \
fma-io-provider.c \
fma-io-provider.h \
- na-ioption.c \
- na-ioption.h \
- na-ioptions-list.c \
- na-ioptions-list.h \
+ fma-ioption.c \
+ fma-ioption.h \
+ fma-ioptions-list.c \
+ fma-ioptions-list.h \
na-iprefs.c \
na-iprefs.h \
na-module.c \
diff --git a/src/core/fma-export-format.c b/src/core/fma-export-format.c
index 4cf8a95..80f1338 100644
--- a/src/core/fma-export-format.c
+++ b/src/core/fma-export-format.c
@@ -32,7 +32,7 @@
#endif
#include "fma-export-format.h"
-#include "na-ioption.h"
+#include "fma-ioption.h"
/* private class data
*/
@@ -55,14 +55,14 @@ static GObjectClass *st_parent_class = NULL;
static GType register_type( void );
static void class_init( FMAExportFormatClass *klass );
-static void ioption_iface_init( NAIOptionInterface *iface, void *user_data );
+static void ioption_iface_init( FMAIOptionInterface *iface, void *user_data );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_dispose( GObject *object );
static void instance_finalize( GObject *object );
-static gchar *ioption_get_id( const NAIOption *option );
-static gchar *ioption_get_label( const NAIOption *option );
-static gchar *ioption_get_description( const NAIOption *option );
-static GdkPixbuf *ioption_get_pixbuf( const NAIOption *option );
+static gchar *ioption_get_id( const FMAIOption *option );
+static gchar *ioption_get_label( const FMAIOption *option );
+static gchar *ioption_get_description( const FMAIOption *option );
+static GdkPixbuf *ioption_get_pixbuf( const FMAIOption *option );
GType
fma_export_format_get_type( void )
@@ -104,7 +104,7 @@ register_type( void )
type = g_type_register_static( G_TYPE_OBJECT, "FMAExportFormat", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTION, &ioption_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTION, &ioption_iface_info );
return( type );
}
@@ -127,7 +127,7 @@ class_init( FMAExportFormatClass *klass )
}
static void
-ioption_iface_init( NAIOptionInterface *iface, void *user_data )
+ioption_iface_init( FMAIOptionInterface *iface, void *user_data )
{
static const gchar *thisfn = "fma_export_format_ioption_iface_init";
@@ -141,13 +141,13 @@ ioption_iface_init( NAIOptionInterface *iface, void *user_data )
/*
* ioption_get_id:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the ASCII id of the @option, as a newly allocated string which
* should be g_free() by the caller.
*/
static gchar *
-ioption_get_id( const NAIOption *option )
+ioption_get_id( const FMAIOption *option )
{
gchar *id;
FMAExportFormat *format;
@@ -166,13 +166,13 @@ ioption_get_id( const NAIOption *option )
/*
* ioption_get_label:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the label associated to @option, as a newly allocated string
* which should be g_free() by the caller.
*/
static gchar *
-ioption_get_label( const NAIOption *option )
+ioption_get_label( const FMAIOption *option )
{
gchar *label;
FMAExportFormat *format;
@@ -191,13 +191,13 @@ ioption_get_label( const NAIOption *option )
/*
* ioption_get_description:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the description associated to @option, as a newly allocated string
* which should be g_free() by the caller.
*/
static gchar *
-ioption_get_description( const NAIOption *option )
+ioption_get_description( const FMAIOption *option )
{
gchar *description;
FMAExportFormat *format;
@@ -216,13 +216,13 @@ ioption_get_description( const NAIOption *option )
/*
* ioption_get_pixbuf:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: a new reference to the pixbuf associated to @option;
* which should later be g_object_unref() by the caller.
*/
static GdkPixbuf *
-ioption_get_pixbuf( const NAIOption *option )
+ioption_get_pixbuf( const FMAIOption *option )
{
GdkPixbuf *pixbuf;
FMAExportFormat *format;
diff --git a/src/core/fma-exporter.c b/src/core/fma-exporter.c
index 1df9166..cd9cb38 100644
--- a/src/core/fma-exporter.c
+++ b/src/core/fma-exporter.c
@@ -197,7 +197,7 @@ fma_exporter_free_formats( GList *formats )
*
* Since: 3.2
*/
-NAIOption *
+FMAIOption *
fma_exporter_get_ask_option( void )
{
static const gchar *thisfn = "fma_exporter_get_ask_option";
@@ -236,7 +236,7 @@ fma_exporter_get_ask_option( void )
g_free( str->format );
g_free( str );
- return( NA_IOPTION( format ));
+ return( FMA_IOPTION( format ));
}
static void
@@ -428,7 +428,7 @@ fma_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
for( ifmt = formats ; ifmt && !exporter ; ifmt = ifmt->next ){
export_format = FMA_EXPORT_FORMAT( ifmt->data );
- id = na_ioption_get_id( NA_IOPTION( export_format ));
+ id = fma_ioption_get_id( FMA_IOPTION( export_format ));
if( !strcmp( id, format )){
exporter = fma_export_format_get_provider( FMA_EXPORT_FORMAT( ifmt->data ));
}
diff --git a/src/core/fma-exporter.h b/src/core/fma-exporter.h
index 11fd345..5989ca4 100644
--- a/src/core/fma-exporter.h
+++ b/src/core/fma-exporter.h
@@ -38,7 +38,7 @@
#include <api/fma-iexporter.h>
#include <api/fma-object-api.h>
-#include "na-ioption.h"
+#include "fma-ioption.h"
#include "na-pivot.h"
G_BEGIN_DECLS
@@ -48,7 +48,7 @@ G_BEGIN_DECLS
GList *fma_exporter_get_formats ( const NAPivot *pivot );
void fma_exporter_free_formats ( GList *formats );
-NAIOption *fma_exporter_get_ask_option ( void );
+FMAIOption *fma_exporter_get_ask_option ( void );
gchar *fma_exporter_to_buffer ( const NAPivot *pivot,
const FMAObjectItem *item,
diff --git a/src/core/fma-import-mode.c b/src/core/fma-import-mode.c
index 6f11fe9..4699b68 100644
--- a/src/core/fma-import-mode.c
+++ b/src/core/fma-import-mode.c
@@ -34,7 +34,7 @@
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "fma-import-mode.h"
-#include "na-ioption.h"
+#include "fma-ioption.h"
/* private class data
*/
@@ -73,11 +73,11 @@ static GObjectClass *st_parent_class = NULL;
static GType register_type( void );
static void class_init( FMAImportModeClass *klass );
-static void ioption_iface_init( NAIOptionInterface *iface, void *user_data );
-static gchar *ioption_get_id( const NAIOption *option );
-static gchar *ioption_get_label( const NAIOption *option );
-static gchar *ioption_get_description( const NAIOption *option );
-static GdkPixbuf *ioption_get_pixbuf( const NAIOption *option );
+static void ioption_iface_init( FMAIOptionInterface *iface, void *user_data );
+static gchar *ioption_get_id( const FMAIOption *option );
+static gchar *ioption_get_label( const FMAIOption *option );
+static gchar *ioption_get_description( const FMAIOption *option );
+static GdkPixbuf *ioption_get_pixbuf( const FMAIOption *option );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_get_property( GObject *object, guint property_id, GValue *value, GParamSpec *spec
);
static void instance_set_property( GObject *object, guint property_id, const GValue *value, GParamSpec
*spec );
@@ -124,7 +124,7 @@ register_type( void )
type = g_type_register_static( G_TYPE_OBJECT, "FMAImportMode", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTION, &ioption_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTION, &ioption_iface_info );
return( type );
}
@@ -180,7 +180,7 @@ class_init( FMAImportModeClass *klass )
}
static void
-ioption_iface_init( NAIOptionInterface *iface, void *user_data )
+ioption_iface_init( FMAIOptionInterface *iface, void *user_data )
{
static const gchar *thisfn = "fma_import_mode_ioption_iface_init";
@@ -194,13 +194,13 @@ ioption_iface_init( NAIOptionInterface *iface, void *user_data )
/*
* ioption_get_id:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the ASCII id of the @option, as a newly allocated string which
* should be g_free() by the caller.
*/
static gchar *
-ioption_get_id( const NAIOption *option )
+ioption_get_id( const FMAIOption *option )
{
gchar *id;
FMAImportMode *mode;
@@ -219,13 +219,13 @@ ioption_get_id( const NAIOption *option )
/*
* ioption_get_label:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the label associated to @option, as a newly allocated string
* which should be g_free() by the caller.
*/
static gchar *
-ioption_get_label( const NAIOption *option )
+ioption_get_label( const FMAIOption *option )
{
gchar *label;
FMAImportMode *mode;
@@ -244,13 +244,13 @@ ioption_get_label( const NAIOption *option )
/*
* ioption_get_description:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: the description associated to @option, as a newly allocated string
* which should be g_free() by the caller.
*/
static gchar *
-ioption_get_description( const NAIOption *option )
+ioption_get_description( const FMAIOption *option )
{
gchar *description;
FMAImportMode *mode;
@@ -269,13 +269,13 @@ ioption_get_description( const NAIOption *option )
/*
* ioption_get_pixbuf:
- * @option: this #NAIOption instance.
+ * @option: this #FMAIOption instance.
*
* Returns: a new reference to the pixbuf associated to @option;
* which should later be g_object_unref() by the caller.
*/
static GdkPixbuf *
-ioption_get_pixbuf( const NAIOption *option )
+ioption_get_pixbuf( const FMAIOption *option )
{
GdkPixbuf *pixbuf;
FMAImportMode *mode;
diff --git a/src/core/fma-importer-ask.c b/src/core/fma-importer-ask.c
index d1f13f2..d9a0cd0 100644
--- a/src/core/fma-importer-ask.c
+++ b/src/core/fma-importer-ask.c
@@ -40,7 +40,7 @@
#include "fma-import-mode.h"
#include "fma-importer.h"
#include "fma-importer-ask.h"
-#include "na-ioptions-list.h"
+#include "fma-ioptions-list.h"
#include "na-settings.h"
/* private class data
@@ -66,9 +66,9 @@ static const gchar *st_uixml = PKGUIDIR "/fma-importer-ask.ui";
static GType register_type( void );
static void class_init( FMAImporterAskClass *klass );
-static void ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data );
-static GList *ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container );
-static void ioptions_list_free_modes( const NAIOptionsList *instance, GtkWidget *container, GList
*modes );
+static void ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data );
+static GList *ioptions_list_get_modes( const FMAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_free_modes( const FMAIOptionsList *instance, GtkWidget *container, GList
*modes );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_dispose( GObject *dialog );
static void instance_finalize( GObject *dialog );
@@ -119,7 +119,7 @@ register_type( void )
type = g_type_register_static( G_TYPE_OBJECT, "FMAImporterAsk", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
return( type );
}
@@ -142,7 +142,7 @@ class_init( FMAImporterAskClass *klass )
}
static void
-ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
+ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data )
{
static const gchar *thisfn = "nact_assistant_import_ioptions_list_iface_init";
@@ -153,7 +153,7 @@ ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
}
static GList *
-ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container )
+ioptions_list_get_modes( const FMAIOptionsList *instance, GtkWidget *container )
{
GList *modes;
@@ -165,7 +165,7 @@ ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container )
}
static void
-ioptions_list_free_modes( const NAIOptionsList *instance, GtkWidget *container, GList *modes )
+ioptions_list_free_modes( const FMAIOptionsList *instance, GtkWidget *container, GList *modes )
{
g_return_if_fail( FMA_IS_IMPORTER_ASK( instance ));
@@ -375,7 +375,7 @@ initialize_gtk( FMAImporterAsk *dialog, GtkWindow *toplevel )
g_debug( "%s: dialog=%p, toplevel=%p", thisfn, ( void * ) dialog, ( void * ) toplevel );
container = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( toplevel ), "AskModeVBox" );
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( dialog ), container, FALSE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( dialog ), container, FALSE );
}
static void
@@ -414,7 +414,7 @@ initialize_window( FMAImporterAsk *editor, GtkWindow *toplevel )
widget = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( toplevel ), "AskModeVBox" );
mode_id = na_settings_get_string( NA_IPREFS_IMPORT_ASK_USER_LAST_MODE, NULL, NULL );
- na_ioptions_list_set_default( NA_IOPTIONS_LIST( editor ), widget, mode_id );
+ fma_ioptions_list_set_default( FMA_IOPTIONS_LIST( editor ), widget, mode_id );
g_free( mode_id );
button = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( toplevel ), "AskKeepChoiceButton" );
@@ -428,15 +428,15 @@ static void
get_selected_mode( FMAImporterAsk *editor )
{
GtkWidget *widget;
- NAIOption *mode;
+ FMAIOption *mode;
gchar *mode_id;
GtkWidget *button;
gboolean keep;
widget = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( editor->private->toplevel ), "AskModeVBox"
);
- mode = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( editor ), widget );
+ mode = fma_ioptions_list_get_selected( FMA_IOPTIONS_LIST( editor ), widget );
- mode_id = na_ioption_get_id( mode );
+ mode_id = fma_ioption_get_id( mode );
na_settings_set_string( NA_IPREFS_IMPORT_ASK_USER_LAST_MODE, mode_id );
g_free( mode_id );
diff --git a/src/core/fma-importer.c b/src/core/fma-importer.c
index 1b94f85..bbd755f 100644
--- a/src/core/fma-importer.c
+++ b/src/core/fma-importer.c
@@ -95,7 +95,7 @@ static FMAObjectItem *is_importing_already_exists( FMAImporterParms *parms,
static void renumber_label_item( FMAObjectItem *item );
static guint ask_user_for_mode( const FMAObjectItem *importing, const FMAObjectItem *existing,
FMAImporterAskUserParms *parms );
static guint get_id_from_string( const gchar *str );
-static NAIOption *get_mode_from_struct( const FMAImportModeStr *str );
+static FMAIOption *get_mode_from_struct( const FMAImportModeStr *str );
/* i18n: '%s' stands for the file URI */
#define ERR_NOT_LOADABLE _( "%s is not loadable (empty or too big or not a regular file)" )
@@ -473,7 +473,7 @@ fma_importer_get_modes( void )
{
static const gchar *thisfn = "fma_importer_get_modes";
GList *modes;
- NAIOption *mode;
+ FMAIOption *mode;
guint i;
g_debug( "%s", thisfn );
@@ -488,7 +488,7 @@ fma_importer_get_modes( void )
return( modes );
}
-static NAIOption *
+static FMAIOption *
get_mode_from_struct( const FMAImportModeStr *str )
{
FMAImportMode *mode;
@@ -515,7 +515,7 @@ get_mode_from_struct( const FMAImportModeStr *str )
FMA_IMPORT_PROP_IMAGE, pixbuf,
NULL );
- return( NA_IOPTION( mode ));
+ return( FMA_IOPTION( mode ));
}
/*
@@ -540,7 +540,7 @@ fma_importer_free_modes( GList *modes )
*
* Returns: a #FMAImportMode object which describes the 'Ask me' option.
*/
-NAIOption *
+FMAIOption *
fma_importer_get_ask_mode( void )
{
static const gchar *thisfn = "fma_importer_get_ask_mode";
diff --git a/src/core/fma-importer.h b/src/core/fma-importer.h
index 05aad2a..be2d087 100644
--- a/src/core/fma-importer.h
+++ b/src/core/fma-importer.h
@@ -60,7 +60,7 @@
#include <api/fma-iimporter.h>
#include <api/fma-object-item.h>
-#include "na-ioption.h"
+#include "fma-ioption.h"
#include "na-pivot.h"
G_BEGIN_DECLS
@@ -148,7 +148,7 @@ void fma_importer_free_result ( FMAImporterResult *result );
GList *fma_importer_get_modes ( void );
void fma_importer_free_modes ( GList *modes );
-NAIOption *fma_importer_get_ask_mode ( void );
+FMAIOption *fma_importer_get_ask_mode ( void );
G_END_DECLS
diff --git a/src/core/na-ioption.c b/src/core/fma-ioption.c
similarity index 61%
rename from src/core/na-ioption.c
rename to src/core/fma-ioption.c
index a178258..7e8dd65 100644
--- a/src/core/na-ioption.c
+++ b/src/core/fma-ioption.c
@@ -31,11 +31,11 @@
#include <config.h>
#endif
-#include "na-ioption.h"
+#include "fma-ioption.h"
/* private interface data
*/
-struct _NAIOptionInterfacePrivate {
+struct _FMAIOptionInterfacePrivate {
void *empty; /* so that gcc -pedantic is happy */
};
@@ -53,20 +53,20 @@ typedef struct {
static guint st_initializations = 0; /* interface initialization count */
static GType register_type( void );
-static void interface_base_init( NAIOptionInterface *iface );
-static void interface_base_finalize( NAIOptionInterface *iface );
+static void interface_base_init( FMAIOptionInterface *iface );
+static void interface_base_finalize( FMAIOptionInterface *iface );
-static guint ioption_get_version( const NAIOption *instance );
-static IOptionData *get_ioption_data( NAIOption *instance );
-static void on_instance_finalized( gpointer user_data, NAIOption *instance );
+static guint ioption_get_version( const FMAIOption *instance );
+static IOptionData *get_ioption_data( FMAIOption *instance );
+static void on_instance_finalized( gpointer user_data, FMAIOption *instance );
/**
- * na_ioption_get_type:
+ * fma_ioption_get_type:
*
* Returns: the #GType type of this interface.
*/
GType
-na_ioption_get_type( void )
+fma_ioption_get_type( void )
{
static GType type = 0;
@@ -78,18 +78,18 @@ na_ioption_get_type( void )
}
/*
- * na_ioption_register_type:
+ * fma_ioption_register_type:
*
* Registers this interface.
*/
static GType
register_type( void )
{
- static const gchar *thisfn = "na_ioption_register_type";
+ static const gchar *thisfn = "fma_ioption_register_type";
GType type;
static const GTypeInfo info = {
- sizeof( NAIOptionInterface ),
+ sizeof( FMAIOptionInterface ),
( GBaseInitFunc ) interface_base_init,
( GBaseFinalizeFunc ) interface_base_finalize,
NULL,
@@ -102,7 +102,7 @@ register_type( void )
g_debug( "%s", thisfn );
- type = g_type_register_static( G_TYPE_INTERFACE, "NAIOption", &info, 0 );
+ type = g_type_register_static( G_TYPE_INTERFACE, "FMAIOption", &info, 0 );
g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
@@ -110,15 +110,15 @@ register_type( void )
}
static void
-interface_base_init( NAIOptionInterface *iface )
+interface_base_init( FMAIOptionInterface *iface )
{
- static const gchar *thisfn = "na_ioption_interface_base_init";
+ static const gchar *thisfn = "fma_ioption_interface_base_init";
if( !st_initializations ){
g_debug( "%s: iface=%p (%s)", thisfn, ( void * ) iface, G_OBJECT_CLASS_NAME( iface ));
- iface->private = g_new0( NAIOptionInterfacePrivate, 1 );
+ iface->private = g_new0( FMAIOptionInterfacePrivate, 1 );
iface->get_version = ioption_get_version;
}
@@ -127,9 +127,9 @@ interface_base_init( NAIOptionInterface *iface )
}
static void
-interface_base_finalize( NAIOptionInterface *iface )
+interface_base_finalize( FMAIOptionInterface *iface )
{
- static const gchar *thisfn = "na_ioption_interface_base_finalize";
+ static const gchar *thisfn = "fma_ioption_interface_base_finalize";
st_initializations -= 1;
@@ -142,13 +142,13 @@ interface_base_finalize( NAIOptionInterface *iface )
}
static guint
-ioption_get_version( const NAIOption *instance )
+ioption_get_version( const FMAIOption *instance )
{
return( 1 );
}
static IOptionData *
-get_ioption_data( NAIOption *instance )
+get_ioption_data( FMAIOption *instance )
{
IOptionData *data;
@@ -166,9 +166,9 @@ get_ioption_data( NAIOption *instance )
}
static void
-on_instance_finalized( gpointer user_data, NAIOption *instance )
+on_instance_finalized( gpointer user_data, FMAIOption *instance )
{
- static const gchar *thisfn = "na_ioption_on_instance_finalized";
+ static const gchar *thisfn = "fma_ioption_on_instance_finalized";
IOptionData *data;
g_debug( "%s: user_data=%p, instance=%p", thisfn, ( void * ) user_data, ( void * ) instance );
@@ -179,96 +179,96 @@ on_instance_finalized( gpointer user_data, NAIOption *instance )
}
/*
- * na_ioption_get_id:
- * @option: this #NAIOption instance.
+ * fma_ioption_get_id:
+ * @option: this #FMAIOption instance.
*
* Returns: the string identifier of the format, as a newly
* allocated string which should be g_free() by the caller.
*/
gchar *
-na_ioption_get_id( const NAIOption *option )
+fma_ioption_get_id( const FMAIOption *option )
{
gchar *id;
- g_return_val_if_fail( NA_IS_IOPTION( option ), NULL );
+ g_return_val_if_fail( FMA_IS_IOPTION( option ), NULL );
- get_ioption_data( NA_IOPTION( option ));
+ get_ioption_data( FMA_IOPTION( option ));
id = NULL;
- if( NA_IOPTION_GET_INTERFACE( option )->get_id ){
- id = NA_IOPTION_GET_INTERFACE( option )->get_id( option );
+ if( FMA_IOPTION_GET_INTERFACE( option )->get_id ){
+ id = FMA_IOPTION_GET_INTERFACE( option )->get_id( option );
}
return( id );
}
/*
- * na_ioption_get_label:
- * @option: this #NAIOption instance.
+ * fma_ioption_get_label:
+ * @option: this #FMAIOption instance.
*
* Returns: the UTF-8 localizable label of the format, as a newly
* allocated string which should be g_free() by the caller.
*/
gchar *
-na_ioption_get_label( const NAIOption *option )
+fma_ioption_get_label( const FMAIOption *option )
{
gchar *label;
- g_return_val_if_fail( NA_IS_IOPTION( option ), NULL );
+ g_return_val_if_fail( FMA_IS_IOPTION( option ), NULL );
- get_ioption_data( NA_IOPTION( option ));
+ get_ioption_data( FMA_IOPTION( option ));
label = NULL;
- if( NA_IOPTION_GET_INTERFACE( option )->get_label ){
- label = NA_IOPTION_GET_INTERFACE( option )->get_label( option );
+ if( FMA_IOPTION_GET_INTERFACE( option )->get_label ){
+ label = FMA_IOPTION_GET_INTERFACE( option )->get_label( option );
}
return( label );
}
/*
- * na_ioption_get_description:
+ * fma_ioption_get_description:
* @format: this #FMAExportFormat object.
*
* Returns: the UTF-8 localizable description of the format, as a newly
* allocated string which should be g_free() by the caller.
*/
gchar *
-na_ioption_get_description( const NAIOption *option )
+fma_ioption_get_description( const FMAIOption *option )
{
gchar *description;
- g_return_val_if_fail( NA_IS_IOPTION( option ), NULL );
+ g_return_val_if_fail( FMA_IS_IOPTION( option ), NULL );
- get_ioption_data( NA_IOPTION( option ));
+ get_ioption_data( FMA_IOPTION( option ));
description = NULL;
- if( NA_IOPTION_GET_INTERFACE( option )->get_description ){
- description = NA_IOPTION_GET_INTERFACE( option )->get_description( option );
+ if( FMA_IOPTION_GET_INTERFACE( option )->get_description ){
+ description = FMA_IOPTION_GET_INTERFACE( option )->get_description( option );
}
return( description );
}
/*
- * na_ioption_get_pixbuf:
- * @option: this #NAIOption instance.
+ * fma_ioption_get_pixbuf:
+ * @option: this #FMAIOption instance.
*
* Returns: a new reference to the #GdkPixbuf image associated with this format,
* or %NULL.
*/
GdkPixbuf *
-na_ioption_get_pixbuf( const NAIOption *option )
+fma_ioption_get_pixbuf( const FMAIOption *option )
{
GdkPixbuf *pixbuf;
- g_return_val_if_fail( NA_IS_IOPTION( option ), NULL );
+ g_return_val_if_fail( FMA_IS_IOPTION( option ), NULL );
- get_ioption_data( NA_IOPTION( option ));
+ get_ioption_data( FMA_IOPTION( option ));
pixbuf = NULL;
- if( NA_IOPTION_GET_INTERFACE( option )->get_pixbuf ){
- pixbuf = NA_IOPTION_GET_INTERFACE( option )->get_pixbuf( option );
+ if( FMA_IOPTION_GET_INTERFACE( option )->get_pixbuf ){
+ pixbuf = FMA_IOPTION_GET_INTERFACE( option )->get_pixbuf( option );
}
return( pixbuf );
diff --git a/src/core/na-ioptions-list.c b/src/core/fma-ioptions-list.c
similarity index 74%
rename from src/core/na-ioptions-list.c
rename to src/core/fma-ioptions-list.c
index 762d7c8..45e914c 100644
--- a/src/core/na-ioptions-list.c
+++ b/src/core/fma-ioptions-list.c
@@ -36,11 +36,11 @@
#include <api/fma-core-utils.h>
#include "fma-gtk-utils.h"
-#include "na-ioptions-list.h"
+#include "fma-ioptions-list.h"
/* private interface data
*/
-struct _NAIOptionsListInterfacePrivate {
+struct _FMAIOptionsListInterfacePrivate {
void *empty; /* so that gcc -pedantic is happy */
};
@@ -71,52 +71,52 @@ enum {
static guint st_initializations = 0; /* interface initialization count */
static GType register_type( void );
-static void interface_base_init( NAIOptionsListInterface *iface );
-static void interface_base_finalize( NAIOptionsListInterface *iface );
-
-static guint ioptions_list_get_version( const NAIOptionsList *instance );
-static void ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container_parent,
GList *options );
-static void ioptions_list_free_ask_option( const NAIOptionsList *instance, GtkWidget
*container_parent, NAIOption *option );
-static GList *options_list_get_options( const NAIOptionsList *instance, GtkWidget *container_parent );
-static void options_list_free_options( const NAIOptionsList *instance, GtkWidget *container_parent,
GList *options );
-static NAIOption *options_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container_parent
);
-static void options_list_free_ask_option( const NAIOptionsList *instance, GtkWidget
*container_parent, NAIOption *ask_option );
+static void interface_base_init( FMAIOptionsListInterface *iface );
+static void interface_base_finalize( FMAIOptionsListInterface *iface );
+
+static guint ioptions_list_get_version( const FMAIOptionsList *instance );
+static void ioptions_list_free_options( const FMAIOptionsList *instance, GtkWidget
*container_parent, GList *options );
+static void ioptions_list_free_ask_option( const FMAIOptionsList *instance, GtkWidget
*container_parent, FMAIOption *option );
+static GList *options_list_get_options( const FMAIOptionsList *instance, GtkWidget *container_parent );
+static void options_list_free_options( const FMAIOptionsList *instance, GtkWidget *container_parent,
GList *options );
+static FMAIOption *options_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget
*container_parent );
+static void options_list_free_ask_option( const FMAIOptionsList *instance, GtkWidget
*container_parent, FMAIOption *ask_option );
static gboolean get_options_list_container_initialized( GtkWidget *container_parent );
static void set_options_list_container_initialized( GtkWidget *container_parent, gboolean
initialized );
static gboolean get_options_list_editable( GtkWidget *container_parent );
static void set_options_list_editable( GtkWidget *container_parent, gboolean editable );
static GtkWidget *get_options_list_first_button( GtkWidget *container );
static void set_options_list_first_button( GtkWidget *container, GtkWidget *button );
-static gboolean get_options_list_instance_initialized( const NAIOptionsList *instance );
-static void set_options_list_instance_initialized( const NAIOptionsList *instance, gboolean
initialized );
-static NAIOption *get_options_list_option( GtkWidget *container );
-static void set_options_list_option( GtkWidget *container, NAIOption *option );
+static gboolean get_options_list_instance_initialized( const FMAIOptionsList *instance );
+static void set_options_list_instance_initialized( const FMAIOptionsList *instance, gboolean
initialized );
+static FMAIOption *get_options_list_option( GtkWidget *container );
+static void set_options_list_option( GtkWidget *container, FMAIOption *option );
static const gchar *get_options_list_option_id( GtkWidget *container );
static void set_options_list_option_id( GtkWidget *container, const gchar *id );
static gboolean get_options_list_sensitive( GtkWidget *container_parent );
static void set_options_list_sensitive( GtkWidget *container_parent, gboolean sensitive );
-static void check_for_initializations( const NAIOptionsList *instance, GtkWidget *container_parent );
+static void check_for_initializations( const FMAIOptionsList *instance, GtkWidget *container_parent
);
static void on_parent_container_finalized( gpointer user_data, GObject *container );
static void on_instance_finalized( gpointer user_data, GObject *instance );
-static void radio_button_create_group( const NAIOptionsList *instance, GtkWidget *container_parent,
gboolean with_ask );
-static void radio_button_draw_vbox( GtkWidget *container_parent, const NAIOption *option );
-static void radio_button_weak_notify( NAIOption *option, GObject *vbox );
-static void tree_view_create_model( const NAIOptionsList *instance, GtkWidget *container_parent );
-static void tree_view_populate( const NAIOptionsList *instance, GtkWidget *container_parent,
gboolean with_ask );
-static void tree_view_add_item( GtkTreeView *listview, GtkTreeModel *model, const NAIOption *option
);
+static void radio_button_create_group( const FMAIOptionsList *instance, GtkWidget *container_parent,
gboolean with_ask );
+static void radio_button_draw_vbox( GtkWidget *container_parent, const FMAIOption *option );
+static void radio_button_weak_notify( FMAIOption *option, GObject *vbox );
+static void tree_view_create_model( const FMAIOptionsList *instance, GtkWidget *container_parent );
+static void tree_view_populate( const FMAIOptionsList *instance, GtkWidget *container_parent,
gboolean with_ask );
+static void tree_view_add_item( GtkTreeView *listview, GtkTreeModel *model, const FMAIOption *option
);
static void tree_view_weak_notify( GtkTreeModel *model, GObject *tree_view );
static void radio_button_select_iter( GtkWidget *container_option, GtkWidget *container_parent );
static gboolean tree_view_select_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
GtkWidget *container_parent );
static void radio_button_get_selected_iter( GtkWidget *container_option, GtkWidget *container_parent
);
-static void tree_view_get_selected( const NAIOptionsList *instance, GtkWidget *container_parent );
+static void tree_view_get_selected( const FMAIOptionsList *instance, GtkWidget *container_parent );
/**
- * na_ioptions_list_get_type:
+ * fma_ioptions_list_get_type:
*
* Returns: the #GType type of this interface.
*/
GType
-na_ioptions_list_get_type( void )
+fma_ioptions_list_get_type( void )
{
static GType type = 0;
@@ -128,18 +128,18 @@ na_ioptions_list_get_type( void )
}
/*
- * na_ioptions_list_register_type:
+ * fma_ioptions_list_register_type:
*
* Registers this interface.
*/
static GType
register_type( void )
{
- static const gchar *thisfn = "na_ioptions_list_register_type";
+ static const gchar *thisfn = "fma_ioptions_list_register_type";
GType type;
static const GTypeInfo info = {
- sizeof( NAIOptionsListInterface ),
+ sizeof( FMAIOptionsListInterface ),
( GBaseInitFunc ) interface_base_init,
( GBaseFinalizeFunc ) interface_base_finalize,
NULL,
@@ -152,7 +152,7 @@ register_type( void )
g_debug( "%s", thisfn );
- type = g_type_register_static( G_TYPE_INTERFACE, "NAIOptionsList", &info, 0 );
+ type = g_type_register_static( G_TYPE_INTERFACE, "FMAIOptionsList", &info, 0 );
g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
@@ -160,15 +160,15 @@ register_type( void )
}
static void
-interface_base_init( NAIOptionsListInterface *iface )
+interface_base_init( FMAIOptionsListInterface *iface )
{
- static const gchar *thisfn = "na_ioptions_list_interface_base_init";
+ static const gchar *thisfn = "fma_ioptions_list_interface_base_init";
if( !st_initializations ){
g_debug( "%s: iface=%p (%s)", thisfn, ( void * ) iface, G_OBJECT_CLASS_NAME( iface ));
- iface->private = g_new0( NAIOptionsListInterfacePrivate, 1 );
+ iface->private = g_new0( FMAIOptionsListInterfacePrivate, 1 );
iface->get_version = ioptions_list_get_version;
iface->get_options = NULL;
@@ -181,9 +181,9 @@ interface_base_init( NAIOptionsListInterface *iface )
}
static void
-interface_base_finalize( NAIOptionsListInterface *iface )
+interface_base_finalize( FMAIOptionsListInterface *iface )
{
- static const gchar *thisfn = "na_ioptions_list_interface_base_finalize";
+ static const gchar *thisfn = "fma_ioptions_list_interface_base_finalize";
st_initializations -= 1;
@@ -199,15 +199,15 @@ interface_base_finalize( NAIOptionsListInterface *iface )
* defaults implemented by the interface
*/
static guint
-ioptions_list_get_version( const NAIOptionsList *instance )
+ioptions_list_get_version( const FMAIOptionsList *instance )
{
return( 1 );
}
static void
-ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container_parent, GList *options )
+ioptions_list_free_options( const FMAIOptionsList *instance, GtkWidget *container_parent, GList *options )
{
- static const gchar *thisfn = "na_ioptions_list_free_options";
+ static const gchar *thisfn = "fma_ioptions_list_free_options";
g_debug( "%s: instance=%p, container_parent=%p, options=%p",
thisfn, ( void * ) instance, ( void * ) container_parent, ( void * ) options );
@@ -217,9 +217,9 @@ ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container
}
static void
-ioptions_list_free_ask_option( const NAIOptionsList *instance, GtkWidget *container_parent, NAIOption
*ask_option )
+ioptions_list_free_ask_option( const FMAIOptionsList *instance, GtkWidget *container_parent, FMAIOption
*ask_option )
{
- static const gchar *thisfn = "na_ioptions_list_free_ask_option";
+ static const gchar *thisfn = "fma_ioptions_list_free_ask_option";
g_debug( "%s: instance=%p, container_parent=%p, ask_option=%p",
thisfn, ( void * ) instance, ( void * ) container_parent, ( void * ) ask_option );
@@ -232,46 +232,46 @@ ioptions_list_free_ask_option( const NAIOptionsList *instance, GtkWidget *contai
* or the default provided by the interface
*/
static GList *
-options_list_get_options( const NAIOptionsList *instance, GtkWidget *container_parent )
+options_list_get_options( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
GList *options;
options = NULL;
- if( NA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_options ){
- options = NA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_options( instance, container_parent
);
+ if( FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_options ){
+ options = FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_options( instance,
container_parent );
}
return( options );
}
static void
-options_list_free_options( const NAIOptionsList *instance, GtkWidget *container_parent, GList *options )
+options_list_free_options( const FMAIOptionsList *instance, GtkWidget *container_parent, GList *options )
{
- if( NA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_options ){
- NA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_options( instance, container_parent, options
);
+ if( FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_options ){
+ FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_options( instance, container_parent,
options );
}
}
-static NAIOption *
-options_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container_parent )
+static FMAIOption *
+options_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
- NAIOption *option;
+ FMAIOption *option;
option = NULL;
- if( NA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_ask_option ){
- option = NA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_ask_option( instance,
container_parent );
+ if( FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_ask_option ){
+ option = FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->get_ask_option( instance,
container_parent );
}
return( option );
}
static void
-options_list_free_ask_option( const NAIOptionsList *instance, GtkWidget *container_parent, NAIOption
*ask_option )
+options_list_free_ask_option( const FMAIOptionsList *instance, GtkWidget *container_parent, FMAIOption
*ask_option )
{
- if( NA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_ask_option ){
- NA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_ask_option( instance, container_parent,
ask_option );
+ if( FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_ask_option ){
+ FMA_IOPTIONS_LIST_GET_INTERFACE( instance )->free_ask_option( instance, container_parent,
ask_option );
}
}
@@ -347,7 +347,7 @@ set_options_list_first_button( GtkWidget *container_parent, GtkWidget *button )
* finalized
*/
static gboolean
-get_options_list_instance_initialized( const NAIOptionsList *instance )
+get_options_list_instance_initialized( const FMAIOptionsList *instance )
{
gboolean initialized;
@@ -357,7 +357,7 @@ get_options_list_instance_initialized( const NAIOptionsList *instance )
}
static void
-set_options_list_instance_initialized( const NAIOptionsList *instance, gboolean initialized )
+set_options_list_instance_initialized( const FMAIOptionsList *instance, gboolean initialized )
{
g_object_set_data( G_OBJECT( instance ), IOPTIONS_LIST_DATA_INITIALIZED, GUINT_TO_POINTER(
initialized ));
}
@@ -365,14 +365,14 @@ set_options_list_instance_initialized( const NAIOptionsList *instance, gboolean
/* the parent container: the current option
* the option container: the option attached to this container (VBox only)
*/
-static NAIOption *
+static FMAIOption *
get_options_list_option( GtkWidget *container )
{
- return(( NAIOption * ) g_object_get_data( G_OBJECT( container ), IOPTIONS_LIST_DATA_OPTION ));
+ return(( FMAIOption * ) g_object_get_data( G_OBJECT( container ), IOPTIONS_LIST_DATA_OPTION ));
}
static void
-set_options_list_option( GtkWidget *container, NAIOption *option )
+set_options_list_option( GtkWidget *container, FMAIOption *option )
{
g_object_set_data( G_OBJECT( container ), IOPTIONS_LIST_DATA_OPTION, option );
}
@@ -433,9 +433,9 @@ set_options_list_sensitive( GtkWidget *container_parent, gboolean sensitive )
* valid values.
*/
static void
-check_for_initializations( const NAIOptionsList *instance, GtkWidget *container_parent )
+check_for_initializations( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
- static const gchar *thisfn = "na_ioptions_list_check_for_initializations";
+ static const gchar *thisfn = "fma_ioptions_list_check_for_initializations";
if( !get_options_list_instance_initialized( instance )){
@@ -462,7 +462,7 @@ check_for_initializations( const NAIOptionsList *instance, GtkWidget *container_
static void
on_parent_container_finalized( gpointer user_data, GObject *container )
{
- static const gchar *thisfn = "na_ioptions_list_on_parent_container_finalized";
+ static const gchar *thisfn = "fma_ioptions_list_on_parent_container_finalized";
g_debug( "%s: user_data=%p, container=%p", thisfn, ( void * ) user_data, ( void * ) container );
}
@@ -470,14 +470,14 @@ on_parent_container_finalized( gpointer user_data, GObject *container )
static void
on_instance_finalized( gpointer user_data, GObject *instance )
{
- static const gchar *thisfn = "na_ioptions_list_on_instance_finalized";
+ static const gchar *thisfn = "fma_ioptions_list_on_instance_finalized";
g_debug( "%s: user_data=%p, instance=%p", thisfn, ( void * ) user_data, ( void * ) instance );
}
/*
- * na_ioptions_list_gtk_init:
- * @instance: the object which implements this #NAIOptionsList interface.
+ * fma_ioptions_list_gtk_init:
+ * @instance: the object which implements this #FMAIOptionsList interface.
* @container_parent: the #GtkWidget parent container in which we are going to setup the
* list of values. @container_parent may be a #GtkVBox or a #GtkTreeView.
* @with_ask: whether we should also display an 'Ask me' option.
@@ -485,11 +485,11 @@ on_instance_finalized( gpointer user_data, GObject *instance )
* Initialize the gtk objects which will be used to display the selection.
*/
void
-na_ioptions_list_gtk_init( const NAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
+fma_ioptions_list_gtk_init( const FMAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
{
- static const gchar *thisfn = "na_ioptions_list_gtk_init";
+ static const gchar *thisfn = "fma_ioptions_list_gtk_init";
- g_return_if_fail( NA_IS_IOPTIONS_LIST( instance ));
+ g_return_if_fail( FMA_IS_IOPTIONS_LIST( instance ));
check_for_initializations( instance, container_parent );
@@ -512,11 +512,11 @@ na_ioptions_list_gtk_init( const NAIOptionsList *instance, GtkWidget *container_
}
static void
-radio_button_create_group( const NAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
+radio_button_create_group( const FMAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
{
- static const gchar *thisfn = "na_ioptions_list_radio_button_create_group";
+ static const gchar *thisfn = "fma_ioptions_list_radio_button_create_group";
GList *options, *iopt;
- NAIOption *option;
+ FMAIOption *option;
g_debug( "%s: instance=%p, container_parent=%p (%s), with_ask=%s",
thisfn,
@@ -529,7 +529,7 @@ radio_button_create_group( const NAIOptionsList *instance, GtkWidget *container_
/* draw the formats as a group of radio buttons
*/
for( iopt = options ; iopt ; iopt = iopt->next ){
- radio_button_draw_vbox( container_parent, NA_IOPTION( iopt->data ));
+ radio_button_draw_vbox( container_parent, FMA_IOPTION( iopt->data ));
}
options_list_free_options( instance, container_parent, options );
@@ -551,10 +551,10 @@ radio_button_create_group( const NAIOptionsList *instance, GtkWidget *container_
* | +- radio button + label
*/
static void
-radio_button_draw_vbox( GtkWidget *container_parent, const NAIOption *option )
+radio_button_draw_vbox( GtkWidget *container_parent, const FMAIOption *option )
{
#if 0
- static const gchar *thisfn = "na_ioptions_list_radio_button_draw_vbox";
+ static const gchar *thisfn = "fma_ioptions_list_radio_button_draw_vbox";
#endif
gchar *description;
GtkWidget *button;
@@ -563,7 +563,7 @@ radio_button_draw_vbox( GtkWidget *container_parent, const NAIOption *option )
/* first button of the group does not have the property set
*/
- label = na_ioption_get_label( option );
+ label = fma_ioption_get_label( option );
first = get_options_list_first_button( container_parent );
if( first ){
button = gtk_radio_button_new_with_label_from_widget( GTK_RADIO_BUTTON( first ), label );
@@ -574,7 +574,7 @@ radio_button_draw_vbox( GtkWidget *container_parent, const NAIOption *option )
g_free( label );
gtk_button_set_use_underline( GTK_BUTTON( button ), TRUE );
- description = na_ioption_get_description( option );
+ description = fma_ioption_get_description( option );
g_object_set( G_OBJECT( button ), "tooltip-text", description, NULL );
g_free( description );
@@ -589,9 +589,9 @@ radio_button_draw_vbox( GtkWidget *container_parent, const NAIOption *option )
* when destroying the window
*/
static void
-radio_button_weak_notify( NAIOption *option, GObject *vbox )
+radio_button_weak_notify( FMAIOption *option, GObject *vbox )
{
- static const gchar *thisfn = "na_ioptions_list_radio_button_weak_notify";
+ static const gchar *thisfn = "fma_ioptions_list_radio_button_weak_notify";
g_debug( "%s: option=%p, vbox=%p", thisfn, ( void * ) option, ( void * ) vbox );
@@ -599,9 +599,9 @@ radio_button_weak_notify( NAIOption *option, GObject *vbox )
}
static void
-tree_view_create_model( const NAIOptionsList *instance, GtkWidget *container_parent )
+tree_view_create_model( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
- static const gchar *thisfn = "na_ioptions_list_tree_view_create_model";
+ static const gchar *thisfn = "fma_ioptions_list_tree_view_create_model";
GtkListStore *model;
GtkTreeViewColumn *column;
GtkTreeSelection *selection;
@@ -641,11 +641,11 @@ tree_view_create_model( const NAIOptionsList *instance, GtkWidget *container_par
}
static void
-tree_view_populate( const NAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
+tree_view_populate( const FMAIOptionsList *instance, GtkWidget *container_parent, gboolean with_ask )
{
- static const gchar *thisfn = "na_ioptions_list_tree_view_populate";
+ static const gchar *thisfn = "fma_ioptions_list_tree_view_populate";
GtkTreeModel *model;
- NAIOption *option;
+ FMAIOption *option;
GList *options, *iopt;
g_return_if_fail( GTK_IS_TREE_VIEW( container_parent ));
@@ -659,7 +659,7 @@ tree_view_populate( const NAIOptionsList *instance, GtkWidget *container_parent,
options = options_list_get_options( instance, container_parent );
for( iopt = options ; iopt ; iopt = iopt->next ){
- option = NA_IOPTION( iopt->data );
+ option = FMA_IOPTION( iopt->data );
tree_view_add_item( GTK_TREE_VIEW( container_parent ), model, option );
}
@@ -675,16 +675,16 @@ tree_view_populate( const NAIOptionsList *instance, GtkWidget *container_parent,
}
static void
-tree_view_add_item( GtkTreeView *listview, GtkTreeModel *model, const NAIOption *option )
+tree_view_add_item( GtkTreeView *listview, GtkTreeModel *model, const FMAIOption *option )
{
GtkTreeIter iter;
gchar *label, *label2, *description;
GdkPixbuf *pixbuf;
- label = na_ioption_get_label( option );
+ label = fma_ioption_get_label( option );
label2 = fma_core_utils_str_remove_char( label, "_" );
- description = na_ioption_get_description( option );
- pixbuf = na_ioption_get_pixbuf( option );
+ description = fma_ioption_get_description( option );
+ pixbuf = fma_ioption_get_pixbuf( option );
gtk_list_store_append( GTK_LIST_STORE( model ), &iter );
gtk_list_store_set(
GTK_LIST_STORE( model ),
@@ -715,21 +715,21 @@ tree_view_weak_notify( GtkTreeModel *model, GObject *tree_view )
}
/*
- * na_ioptions_list_set_default:
- * @instance: the object which implements this #NAIOptionsList interface.
+ * fma_ioptions_list_set_default:
+ * @instance: the object which implements this #FMAIOptionsList interface.
* @container_parent: the #GtkWidget which embeds our list of values.
- * @default_id: the string identifier of the #NAIOption to be set as the default.
+ * @default_id: the string identifier of the #FMAIOption to be set as the default.
*
* Set the default, either of the radio button group or of the tree view.
*/
void
-na_ioptions_list_set_default(
- const NAIOptionsList *instance, GtkWidget *container_parent, const gchar *default_id )
+fma_ioptions_list_set_default(
+ const FMAIOptionsList *instance, GtkWidget *container_parent, const gchar *default_id )
{
- static const gchar *thisfn = "na_ioptions_list_set_default";
+ static const gchar *thisfn = "fma_ioptions_list_set_default";
GtkTreeModel *model;
- g_return_if_fail( NA_IS_IOPTIONS_LIST( instance ));
+ g_return_if_fail( FMA_IS_IOPTIONS_LIST( instance ));
check_for_initializations( instance, container_parent );
@@ -768,19 +768,19 @@ static void
radio_button_select_iter( GtkWidget *button, GtkWidget *container_parent )
{
const gchar *default_id;
- NAIOption *option;
+ FMAIOption *option;
gboolean editable, sensitive;
gchar *option_id;
default_id = get_options_list_option_id( container_parent );
option = get_options_list_option( button );
- option_id = na_ioption_get_id( option );
+ option_id = fma_ioption_get_id( option );
if( !strcmp( default_id, option_id )){
editable = get_options_list_editable( container_parent );
sensitive = get_options_list_sensitive( container_parent );
fma_gtk_utils_radio_set_initial_state( GTK_RADIO_BUTTON( button ), NULL, NULL, editable,
sensitive );
- g_debug( "na_ioptions_list_radio_button_select_iter: container_parent=%p, set active
button=%p",
+ g_debug( "fma_ioptions_list_radio_button_select_iter: container_parent=%p, set active
button=%p",
( void * ) container_parent, ( void * ) button );
}
@@ -795,7 +795,7 @@ tree_view_select_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
{
gboolean stop;
GtkTreeView *tree_view;
- NAIOption *option;
+ FMAIOption *option;
const gchar *default_id;
gchar *option_id;
GtkTreeSelection *selection;
@@ -807,7 +807,7 @@ tree_view_select_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
gtk_tree_model_get( model, iter, OBJECT_COLUMN, &option, -1 );
g_object_unref( option );
- option_id = na_ioption_get_id( option );
+ option_id = fma_ioption_get_id( option );
if( !strcmp( default_id, option_id )){
selection = gtk_tree_view_get_selection( tree_view );
@@ -821,21 +821,21 @@ tree_view_select_iter( GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter
}
/*
- * na_ioptions_list_set_editable:
- * @instance: the object which implements this #NAIOptionsList interface.
+ * fma_ioptions_list_set_editable:
+ * @instance: the object which implements this #FMAIOptionsList interface.
* @container_parent: the #GtkWidget which embeds our list of values.
* @editable: whether the selectable user's preference is editable;
* Most of time, a user's preference is not editable if it is set as mandatory,
* or if the whole user's preferences are not writable.
*
- * Set the @editable pseudo-property on the @instance #NAIOptionsList instance.
+ * Set the @editable pseudo-property on the @instance #FMAIOptionsList instance.
*/
void
-na_ioptions_list_set_editable( const NAIOptionsList *instance, GtkWidget *container_parent, gboolean
editable )
+fma_ioptions_list_set_editable( const FMAIOptionsList *instance, GtkWidget *container_parent, gboolean
editable )
{
- static const gchar *thisfn = "na_ioptions_list_set_editable";
+ static const gchar *thisfn = "fma_ioptions_list_set_editable";
- g_return_if_fail( NA_IS_IOPTIONS_LIST( instance ));
+ g_return_if_fail( FMA_IS_IOPTIONS_LIST( instance ));
check_for_initializations( instance, container_parent );
@@ -849,21 +849,21 @@ na_ioptions_list_set_editable( const NAIOptionsList *instance, GtkWidget *contai
}
/*
- * na_ioptions_list_set_sensitive:
- * @instance: the object which implements this #NAIOptionsList interface.
+ * fma_ioptions_list_set_sensitive:
+ * @instance: the object which implements this #FMAIOptionsList interface.
* @container_parent: the #GtkWidget which embeds our list of values.
* @sensitive: whether the radio button group is to be sensitive;
* a widget should not be sensitive if the selectable option is not relevant
* in the considered case.
*
- * Set the @sensitive pseudo-property on the @instance #NAIOptionsList instance.
+ * Set the @sensitive pseudo-property on the @instance #FMAIOptionsList instance.
*/
void
-na_ioptions_list_set_sensitive( const NAIOptionsList *instance, GtkWidget *container_parent, gboolean
sensitive )
+fma_ioptions_list_set_sensitive( const FMAIOptionsList *instance, GtkWidget *container_parent, gboolean
sensitive )
{
- static const gchar *thisfn = "na_ioptions_list_set_sensitive";
+ static const gchar *thisfn = "fma_ioptions_list_set_sensitive";
- g_return_if_fail( NA_IS_IOPTIONS_LIST( instance ));
+ g_return_if_fail( FMA_IS_IOPTIONS_LIST( instance ));
check_for_initializations( instance, container_parent );
@@ -877,19 +877,19 @@ na_ioptions_list_set_sensitive( const NAIOptionsList *instance, GtkWidget *conta
}
/*
- * na_ioptions_list_get_selected:
- * @instance: the object which implements this #NAIOptionsList interface.
+ * fma_ioptions_list_get_selected:
+ * @instance: the object which implements this #FMAIOptionsList interface.
* @container_parent: the #GtkWidget which embeds our list of values.
*
- * Returns: the currently selected #NAIOption.
+ * Returns: the currently selected #FMAIOption.
*/
-NAIOption *
-na_ioptions_list_get_selected( const NAIOptionsList *instance, GtkWidget *container_parent )
+FMAIOption *
+fma_ioptions_list_get_selected( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
- static const gchar *thisfn = "na_ioptions_list_get_selected";
- NAIOption *option;
+ static const gchar *thisfn = "fma_ioptions_list_get_selected";
+ FMAIOption *option;
- g_return_val_if_fail( NA_IS_IOPTIONS_LIST( instance ), NULL );
+ g_return_val_if_fail( FMA_IS_IOPTIONS_LIST( instance ), NULL );
check_for_initializations( instance, container_parent );
@@ -919,24 +919,24 @@ na_ioptions_list_get_selected( const NAIOptionsList *instance, GtkWidget *contai
static void
radio_button_get_selected_iter( GtkWidget *button, GtkWidget *container_parent )
{
- NAIOption *option;
+ FMAIOption *option;
if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( button ))){
option = get_options_list_option( button );
set_options_list_option( container_parent, option );
- g_debug( "na_ioptions_list_radio_button_get_selected_iter: container_parent=%p, active
button=%p",
+ g_debug( "fma_ioptions_list_radio_button_get_selected_iter: container_parent=%p, active
button=%p",
( void * ) container_parent, ( void * ) button );
}
}
static void
-tree_view_get_selected( const NAIOptionsList *instance, GtkWidget *container_parent )
+tree_view_get_selected( const FMAIOptionsList *instance, GtkWidget *container_parent )
{
GtkTreeSelection *selection;
GList *rows;
GtkTreeModel *model;
GtkTreeIter iter;
- NAIOption *option;
+ FMAIOption *option;
selection = gtk_tree_view_get_selection( GTK_TREE_VIEW( container_parent ));
rows = gtk_tree_selection_get_selected_rows( selection, &model );
diff --git a/src/nact/nact-assistant-export.c b/src/nact/nact-assistant-export.c
index c5746a7..9d6e02c 100644
--- a/src/nact/nact-assistant-export.c
+++ b/src/nact/nact-assistant-export.c
@@ -40,7 +40,7 @@
#include "core/fma-exporter.h"
#include "core/fma-export-format.h"
#include "core/fma-gtk-utils.h"
-#include "core/na-ioptions-list.h"
+#include "core/fma-ioptions-list.h"
#include "nact-application.h"
#include "nact-main-window.h"
@@ -96,10 +96,10 @@ static BaseAssistantClass *st_parent_class = NULL;
static GType register_type( void );
static void class_init( NactAssistantExportClass *klass );
-static void ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data );
-static GList *ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container );
-static void ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList
*formats );
-static NAIOption *ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data );
+static GList *ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_free_formats( const FMAIOptionsList *instance, GtkWidget *container, GList
*formats );
+static FMAIOption *ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_constructed( GObject *instance );
static void instance_dispose( GObject *instance );
@@ -158,7 +158,7 @@ register_type( void )
type = g_type_register_static( BASE_TYPE_ASSISTANT, "NactAssistantExport", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
return( type );
}
@@ -185,7 +185,7 @@ class_init( NactAssistantExportClass *klass )
}
static void
-ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
+ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data )
{
static const gchar *thisfn = "nact_assistant_export_ioptions_list_iface_init";
@@ -197,7 +197,7 @@ ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
}
static GList *
-ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container )
+ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container )
{
NactAssistantExport *window;
NactApplication *application;
@@ -215,13 +215,13 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
}
static void
-ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList *formats )
+ioptions_list_free_formats( const FMAIOptionsList *instance, GtkWidget *container, GList *formats )
{
fma_exporter_free_formats( formats );
}
-static NAIOption *
-ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container )
+static FMAIOption *
+ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container )
{
return( fma_exporter_get_ask_option());
}
@@ -459,7 +459,7 @@ format_tree_view_initialize_gtk( NactAssistantExport *window )
page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FORMAT_SELECTION );
tree_view = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( page ), "p3-ExportFormatTreeView" );
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( window ), tree_view, TRUE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( window ), tree_view, TRUE );
gtk_assistant_set_page_complete( assistant, page, TRUE );
}
@@ -502,11 +502,11 @@ on_base_initialize_base_window( NactAssistantExport *window, void *empty )
page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FORMAT_SELECTION );
tree_view = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( page ),
"p3-ExportFormatTreeView" );
format = na_settings_get_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL, &mandatory );
- na_ioptions_list_set_editable(
- NA_IOPTIONS_LIST( window ), tree_view,
+ fma_ioptions_list_set_editable(
+ FMA_IOPTIONS_LIST( window ), tree_view,
!mandatory && !window->private->preferences_locked );
- na_ioptions_list_set_default(
- NA_IOPTIONS_LIST( window ), tree_view, format );
+ fma_ioptions_list_set_default(
+ FMA_IOPTIONS_LIST( window ), tree_view, format );
g_free( format );
}
}
@@ -666,7 +666,7 @@ assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, Gt
gchar *format_description, *format_description2;
gchar *format_id;
GtkWidget *label;
- NAIOption *format;
+ FMAIOption *format;
GList *it;
GtkWidget *format_page, *tree_view;
@@ -714,10 +714,10 @@ assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, Gt
format_page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FORMAT_SELECTION );
tree_view = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( format_page ),
"p3-ExportFormatTreeView" );
g_return_if_fail( GTK_IS_TREE_VIEW( tree_view ));
- format = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( window ), tree_view );
+ format = fma_ioptions_list_get_selected( FMA_IOPTIONS_LIST( window ), tree_view );
g_return_if_fail( FMA_IS_EXPORT_FORMAT( format ));
- format_label = na_ioption_get_label( format );
+ format_label = fma_ioption_get_label( format );
format_label2 = fma_core_utils_str_remove_char( format_label, "_" );
text = g_strdup_printf( "%s:", format_label2 );
label = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( page ), "p4-ConfirmExportFormat" );
@@ -727,7 +727,7 @@ assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, Gt
g_free( format_label2 );
g_free( text );
- format_description = na_ioption_get_description( format );
+ format_description = fma_ioption_get_description( format );
format_description2 = fma_core_utils_str_remove_char( format_description, "_" );
label = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( page ), "p4-ConfirmExportTooltip" );
g_return_if_fail( GTK_IS_LABEL( label ));
@@ -735,7 +735,7 @@ assist_prepare_confirm( NactAssistantExport *window, GtkAssistant *assistant, Gt
g_free( format_description );
g_free( format_description2 );
- format_id = na_ioption_get_id( format );
+ format_id = fma_ioption_get_id( format );
na_settings_set_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, format_id );
g_free( format_id );
diff --git a/src/nact/nact-assistant-import.c b/src/nact/nact-assistant-import.c
index f33e5da..ac493d3 100644
--- a/src/nact/nact-assistant-import.c
+++ b/src/nact/nact-assistant-import.c
@@ -40,7 +40,7 @@
#include <core/fma-import-mode.h>
#include <core/fma-importer.h>
-#include <core/na-ioptions-list.h>
+#include <core/fma-ioptions-list.h>
#include <core/fma-gtk-utils.h>
#include <core/na-settings.h>
@@ -84,7 +84,7 @@ struct _NactAssistantImportPrivate {
gboolean dispose_has_run;
GtkWidget *file_chooser;
GtkTreeView *duplicates_listview;
- NAIOption *mode;
+ FMAIOption *mode;
GList *results;
GList *overriden;
};
@@ -97,10 +97,10 @@ static BaseAssistantClass *st_parent_class = NULL;
static GType register_type( void );
static void class_init( NactAssistantImportClass *klass );
-static void ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data );
-static GList *ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container );
-static void ioptions_list_free_modes( const NAIOptionsList *instance, GtkWidget *container, GList
*modes );
-static NAIOption *ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data );
+static GList *ioptions_list_get_modes( const FMAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_free_modes( const FMAIOptionsList *instance, GtkWidget *container, GList
*modes );
+static FMAIOption *ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_dispose( GObject *application );
static void instance_finalize( GObject *application );
@@ -165,7 +165,7 @@ register_type( void )
type = g_type_register_static( BASE_TYPE_ASSISTANT, "NactAssistantImport", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
return( type );
}
@@ -191,7 +191,7 @@ class_init( NactAssistantImportClass *klass )
}
static void
-ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
+ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data )
{
static const gchar *thisfn = "nact_assistant_import_ioptions_list_iface_init";
@@ -203,7 +203,7 @@ ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
}
static GList *
-ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container )
+ioptions_list_get_modes( const FMAIOptionsList *instance, GtkWidget *container )
{
GList *modes;
@@ -215,13 +215,13 @@ ioptions_list_get_modes( const NAIOptionsList *instance, GtkWidget *container )
}
static void
-ioptions_list_free_modes( const NAIOptionsList *instance, GtkWidget *container, GList *modes )
+ioptions_list_free_modes( const FMAIOptionsList *instance, GtkWidget *container, GList *modes )
{
fma_importer_free_modes( modes );
}
-static NAIOption *
-ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container )
+static FMAIOption *
+ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container )
{
return( fma_importer_get_ask_mode());
}
@@ -380,7 +380,7 @@ create_duplicates_treeview_model( NactAssistantImport *dialog )
dialog->private->duplicates_listview = get_duplicates_treeview_from_assistant_import( dialog );
g_return_if_fail( GTK_IS_TREE_VIEW( dialog->private->duplicates_listview ));
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( dialog ), GTK_WIDGET(
dialog->private->duplicates_listview ), TRUE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( dialog ), GTK_WIDGET(
dialog->private->duplicates_listview ), TRUE );
}
static void
@@ -535,11 +535,11 @@ runtime_init_duplicates( NactAssistantImport *window, GtkAssistant *assistant )
thisfn, ( void * ) window, ( void * ) assistant );
import_mode = na_settings_get_string( NA_IPREFS_IMPORT_PREFERRED_MODE, NULL, &mandatory );
- na_ioptions_list_set_editable(
- NA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ),
+ fma_ioptions_list_set_editable(
+ FMA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ),
!mandatory );
- na_ioptions_list_set_default(
- NA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ),
+ fma_ioptions_list_set_default(
+ FMA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ),
import_mode );
g_free( import_mode );
@@ -619,12 +619,12 @@ prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget
*/
label = find_widget_from_page( page, "p3-ConfirmImportMode" );
g_return_if_fail( GTK_IS_LABEL( label ));
- window->private->mode = na_ioptions_list_get_selected(
- NA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ));
+ window->private->mode = fma_ioptions_list_get_selected(
+ FMA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ));
g_return_if_fail( FMA_IS_IMPORT_MODE( window->private->mode ));
- mode_label = na_ioption_get_label( window->private->mode );
+ mode_label = fma_ioption_get_label( window->private->mode );
label2 = fma_core_utils_str_remove_char( mode_label, "_" );
- mode_description = na_ioption_get_description( window->private->mode );
+ mode_description = fma_ioption_get_description( window->private->mode );
text = g_markup_printf_escaped( "%s\n\n<span style=\"italic\">%s</span>", label2, mode_description );
gtk_label_set_markup( GTK_LABEL( label ), text );
g_free( text );
@@ -831,7 +831,7 @@ prepare_importdone( NactAssistantImport *window, GtkAssistant *assistant, GtkWid
gtk_box_pack_start( GTK_BOX( file_vbox ), file_report, FALSE, FALSE, 0 );
}
- mode_id = na_ioption_get_id( window->private->mode );
+ mode_id = fma_ioption_get_id( window->private->mode );
na_settings_set_string( NA_IPREFS_IMPORT_PREFERRED_MODE, mode_id );
g_free( mode_id );
diff --git a/src/nact/nact-export-ask.c b/src/nact/nact-export-ask.c
index 0559285..666abc0 100644
--- a/src/nact/nact-export-ask.c
+++ b/src/nact/nact-export-ask.c
@@ -38,7 +38,7 @@
#include "core/fma-exporter.h"
#include "core/fma-export-format.h"
#include "core/fma-gtk-utils.h"
-#include "core/na-ioptions-list.h"
+#include "core/fma-ioptions-list.h"
#include "base-gtk-utils.h"
#include "nact-application.h"
@@ -65,9 +65,9 @@ static BaseDialogClass *st_parent_class = NULL;
static GType register_type( void );
static void class_init( NactExportAskClass *klass );
-static void ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data );
-static GList *ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container );
-static void ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList
*formats );
+static void ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data );
+static GList *ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_free_formats( const FMAIOptionsList *instance, GtkWidget *container, GList
*formats );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_constructed( GObject *dialog );
static void instance_dispose( GObject *dialog );
@@ -120,7 +120,7 @@ register_type( void )
type = g_type_register_static( BASE_TYPE_DIALOG, "NactExportAsk", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
return( type );
}
@@ -142,7 +142,7 @@ class_init( NactExportAskClass *klass )
}
static void
-ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
+ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data )
{
static const gchar *thisfn = "nact_assistant_export_ioptions_list_iface_init";
@@ -153,7 +153,7 @@ ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
}
static GList *
-ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container )
+ioptions_list_get_formats( const FMAIOptionsList *instance, GtkWidget *container )
{
NactExportAsk *window;
NactApplication *application;
@@ -171,7 +171,7 @@ ioptions_list_get_formats( const NAIOptionsList *instance, GtkWidget *container
}
static void
-ioptions_list_free_formats( const NAIOptionsList *instance, GtkWidget *container, GList *formats )
+ioptions_list_free_formats( const FMAIOptionsList *instance, GtkWidget *container, GList *formats )
{
fma_exporter_free_formats( formats );
}
@@ -360,7 +360,7 @@ on_base_initialize_gtk( NactExportAsk *editor, GtkDialog *toplevel, gpointer use
thisfn, ( void * ) editor, ( void * ) toplevel, ( void * ) user_data );
container = base_window_get_widget( BASE_WINDOW( editor ), "export-format-ask" );
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( editor ), container, FALSE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( editor ), container, FALSE );
}
}
@@ -396,11 +396,11 @@ on_base_initialize_window( NactExportAsk *editor, gpointer user_data )
g_free( item_label );
widget = base_window_get_widget( BASE_WINDOW( editor ), "export-format-ask" );
- na_ioptions_list_set_editable(
- NA_IOPTIONS_LIST( editor ), widget,
+ fma_ioptions_list_set_editable(
+ FMA_IOPTIONS_LIST( editor ), widget,
!priv->format_mandatory && !priv->preferences_locked );
- na_ioptions_list_set_default(
- NA_IOPTIONS_LIST( editor ), widget,
+ fma_ioptions_list_set_default(
+ FMA_IOPTIONS_LIST( editor ), widget,
priv->format );
base_gtk_utils_toggle_set_initial_state( BASE_WINDOW( editor ),
@@ -467,18 +467,18 @@ static gchar *
get_export_format( NactExportAsk *editor )
{
GtkWidget *widget;
- NAIOption *format;
+ FMAIOption *format;
gchar *format_id;
widget = base_window_get_widget( BASE_WINDOW( editor ), "export-format-ask" );
- format = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( editor ), widget );
+ format = fma_ioptions_list_get_selected( FMA_IOPTIONS_LIST( editor ), widget );
g_return_val_if_fail( FMA_IS_EXPORT_FORMAT( format ), 0 );
if( !editor->private->keep_last_choice_mandatory ){
na_settings_set_boolean( NA_IPREFS_EXPORT_ASK_USER_KEEP_LAST_CHOICE,
editor->private->keep_last_choice );
}
- format_id = na_ioption_get_id( format );
+ format_id = fma_ioption_get_id( format );
na_settings_set_string( NA_IPREFS_EXPORT_ASK_USER_LAST_FORMAT, format_id );
return( format_id );
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index 3558fa8..c3053d2 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -42,7 +42,7 @@
#include <core/fma-gtk-utils.h>
#include <core/fma-import-mode.h>
#include <core/fma-importer.h>
-#include <core/na-ioptions-list.h>
+#include <core/fma-ioptions-list.h>
#include <core/na-iprefs.h>
#include <core/na-tokens.h>
@@ -127,10 +127,10 @@ static guint st_last_tab = 0;
static GType register_type( void );
static void class_init( NactPreferencesEditorClass *klass );
-static void ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data );
-static GList *ioptions_list_get_options( const NAIOptionsList *instance, GtkWidget *container );
-static void ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container, GList
*options );
-static NAIOption *ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data );
+static GList *ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container );
+static void ioptions_list_free_options( const FMAIOptionsList *instance, GtkWidget *container, GList
*options );
+static FMAIOption *ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container );
static void instance_init( GTypeInstance *instance, gpointer klass );
static void instance_constructed( GObject *dialog );
static void instance_dispose( GObject *dialog );
@@ -211,7 +211,7 @@ register_type( void )
type = g_type_register_static( BASE_TYPE_DIALOG, "NactPreferencesEditor", &info, 0 );
- g_type_add_interface_static( type, NA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
+ g_type_add_interface_static( type, FMA_TYPE_IOPTIONS_LIST, &ioptions_list_iface_info );
return( type );
}
@@ -237,7 +237,7 @@ class_init( NactPreferencesEditorClass *klass )
}
static void
-ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
+ioptions_list_iface_init( FMAIOptionsListInterface *iface, void *user_data )
{
static const gchar *thisfn = "nact_assistant_export_ioptions_list_iface_init";
@@ -254,7 +254,7 @@ ioptions_list_iface_init( NAIOptionsListInterface *iface, void *user_data )
* current container
*/
static GList *
-ioptions_list_get_options( const NAIOptionsList *instance, GtkWidget *container )
+ioptions_list_get_options( const FMAIOptionsList *instance, GtkWidget *container )
{
static const gchar *thisfn = "nact_preferences_editor_ioptions_list_get_options";
GList *options;
@@ -283,7 +283,7 @@ ioptions_list_get_options( const NAIOptionsList *instance, GtkWidget *container
}
static void
-ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container, GList *options )
+ioptions_list_free_options( const FMAIOptionsList *instance, GtkWidget *container, GList *options )
{
static const gchar *thisfn = "nact_preferences_editor_ioptions_list_free_options";
@@ -302,11 +302,11 @@ ioptions_list_free_options( const NAIOptionsList *instance, GtkWidget *container
}
}
-static NAIOption *
-ioptions_list_get_ask_option( const NAIOptionsList *instance, GtkWidget *container )
+static FMAIOption *
+ioptions_list_get_ask_option( const FMAIOptionsList *instance, GtkWidget *container )
{
static const gchar *thisfn = "nact_preferences_editor_ioptions_list_get_ask_option";
- NAIOption *option;
+ FMAIOption *option;
g_return_val_if_fail( NACT_IS_PREFERENCES_EDITOR( instance ), NULL );
@@ -489,10 +489,10 @@ on_base_initialize_gtk( NactPreferencesEditor *editor, GtkDialog *toplevel, gpoi
desktop_create_model( editor );
container = base_window_get_widget( BASE_WINDOW( editor ), "PreferencesImportModeVBox" );
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( editor ), container, TRUE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( editor ), container, TRUE );
container = base_window_get_widget( BASE_WINDOW( editor ), "PreferencesExportFormatVBox" );
- na_ioptions_list_gtk_init( NA_IOPTIONS_LIST( editor ), container, TRUE );
+ fma_ioptions_list_gtk_init( FMA_IOPTIONS_LIST( editor ), container, TRUE );
listview = GTK_TREE_VIEW( base_window_get_widget( BASE_WINDOW( editor ), "SchemesTreeView" ));
nact_schemes_list_create_model( listview, SCHEMES_LIST_FOR_PREFERENCES );
@@ -546,11 +546,11 @@ on_base_initialize_window( NactPreferencesEditor *editor, gpointer user_data )
*/
container = base_window_get_widget( BASE_WINDOW( editor ), "PreferencesImportModeVBox" );
import_mode = na_settings_get_string( NA_IPREFS_IMPORT_PREFERRED_MODE, NULL,
&editor->private->import_mode_mandatory );
- na_ioptions_list_set_editable(
- NA_IOPTIONS_LIST( editor ), container,
+ fma_ioptions_list_set_editable(
+ FMA_IOPTIONS_LIST( editor ), container,
!editor->private->import_mode_mandatory &&
!editor->private->preferences_locked );
- na_ioptions_list_set_default(
- NA_IOPTIONS_LIST( editor ), container,
+ fma_ioptions_list_set_default(
+ FMA_IOPTIONS_LIST( editor ), container,
import_mode );
g_free( import_mode );
@@ -558,11 +558,11 @@ on_base_initialize_window( NactPreferencesEditor *editor, gpointer user_data )
*/
container = base_window_get_widget( BASE_WINDOW( editor ), "PreferencesExportFormatVBox" );
export_format = na_settings_get_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL,
&editor->private->export_format_mandatory );
- na_ioptions_list_set_editable(
- NA_IOPTIONS_LIST( editor ), container,
+ fma_ioptions_list_set_editable(
+ FMA_IOPTIONS_LIST( editor ), container,
!editor->private->export_format_mandatory &&
!editor->private->preferences_locked );
- na_ioptions_list_set_default(
- NA_IOPTIONS_LIST( editor ), container,
+ fma_ioptions_list_set_default(
+ FMA_IOPTIONS_LIST( editor ), container,
export_format );
g_free( export_format );
@@ -1185,7 +1185,7 @@ on_dialog_ok( BaseDialog *dialog )
{
NactPreferencesEditor *editor;
GtkWidget *container;
- NAIOption *option;
+ FMAIOption *option;
gchar *import_mode;
gchar *export_format;
@@ -1244,9 +1244,9 @@ on_dialog_ok( BaseDialog *dialog )
*/
if( !editor->private->import_mode_mandatory ){
container = base_window_get_widget( BASE_WINDOW( editor ),
"PreferencesImportModeVBox" );
- option = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( editor ), container );
+ option = fma_ioptions_list_get_selected( FMA_IOPTIONS_LIST( editor ), container );
g_return_if_fail( FMA_IS_IMPORT_MODE( option ));
- import_mode = na_ioption_get_id( option );
+ import_mode = fma_ioption_get_id( option );
na_settings_set_string( NA_IPREFS_IMPORT_PREFERRED_MODE, import_mode );
g_free( import_mode );
}
@@ -1255,10 +1255,10 @@ on_dialog_ok( BaseDialog *dialog )
*/
if( !editor->private->export_format_mandatory ){
container = base_window_get_widget( BASE_WINDOW( editor ),
"PreferencesExportFormatVBox" );
- option = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( editor ), container );
+ option = fma_ioptions_list_get_selected( FMA_IOPTIONS_LIST( editor ), container );
g_debug( "nact_preferences_editor_on_dialog_ok: option=%p", ( void * ) option );
g_return_if_fail( FMA_IS_EXPORT_FORMAT( option ));
- export_format = na_ioption_get_id( option );
+ export_format = fma_ioption_get_id( option );
na_settings_set_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, export_format );
g_free( export_format );
}
diff --git a/src/utils/nautilus-actions-print.c b/src/utils/nautilus-actions-print.c
index f74d840..80ec61b 100644
--- a/src/utils/nautilus-actions-print.c
+++ b/src/utils/nautilus-actions-print.c
@@ -43,7 +43,7 @@
#include <core/fma-exporter.h>
#include <core/fma-export-format.h>
-#include <core/na-ioption.h>
+#include <core/fma-ioption.h>
#include "console-utils.h"
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/core/na-ioption.h b/src/core/fma-ioption.h
similarity index 60%
rename from src/core/na-ioption.h
rename to src/core/fma-ioption.h
index 51975f4..730d7f1 100644
--- a/src/core/na-ioption.h
+++ b/src/core/fma-ioption.h
@@ -27,22 +27,22 @@
* ... and many others (see AUTHORS)
*/
-#ifndef __CORE_NA_IOPTION_H__
-#define __CORE_NA_IOPTION_H__
+#ifndef __CORE_FMA_IOPTION_H__
+#define __CORE_FMA_IOPTION_H__
/*
* SECTION: ioptions
- * @title: NAIOption
+ * @title: FMAIOption
* @short_description: The Option Interface v 1
- * @include: core/na-ioption.h
+ * @include: core/fma-ioption.h
*
* The #NAIOption interface is to be implemented by #GObject -derived object which
* are part of a #NAIOptionsList interface.
*
* <refsect2>
* <title>Versions historic</title>
* <table>
* <title>Historic of the versions of the #NAIOption interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
* <colspec colname="api-version" />
@@ -50,7 +50,7 @@
* <thead>
* <row>
* <entry>&prodname; version</entry>
- * <entry>#NAIOption interface version</entry>
+ * <entry>#FMAIOption interface version</entry>
* <entry></entry>
* </row>
* </thead>
@@ -70,18 +70,18 @@
G_BEGIN_DECLS
-#define NA_TYPE_IOPTION ( na_ioption_get_type())
-#define NA_IOPTION( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_TYPE_IOPTION,
NAIOption ))
-#define NA_IS_IOPTION( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_IOPTION ))
-#define NA_IOPTION_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_TYPE_IOPTION,
NAIOptionInterface ))
+#define FMA_TYPE_IOPTION ( fma_ioption_get_type())
+#define FMA_IOPTION( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance, FMA_TYPE_IOPTION,
FMAIOption ))
+#define FMA_IS_IOPTION( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance, FMA_TYPE_IOPTION ))
+#define FMA_IOPTION_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ),
FMA_TYPE_IOPTION, FMAIOptionInterface ))
-typedef struct _NAIOption NAIOption;
-typedef struct _NAIOptionInterfacePrivate NAIOptionInterfacePrivate;
-typedef struct _NAIOptionImportFromUriParms NAIOptionImportFromUriParms;
-typedef struct _NAIOptionManageImportModeParms NAIOptionManageImportModeParms;
+typedef struct _FMAIOption FMAIOption;
+typedef struct _FMAIOptionInterfacePrivate FMAIOptionInterfacePrivate;
+typedef struct _FMAIOptionImportFromUriParms FMAIOptionImportFromUriParms;
+typedef struct _FMAIOptionManageImportModeParms FMAIOptionManageImportModeParms;
/*
- * NAIOptionInterface:
+ * FMAIOptionInterface:
* @get_version: returns the version of this interface that the
* instance implements.
* @get_id: returns the string identifier of the option.
@@ -89,17 +89,17 @@ typedef struct _NAIOptionManageImportModeParms NAIOptionManageImportModeParms;
* @get_description: returns the description of the option.
* @get_pixbuf: returns the image associated to the option.
*
* This defines the interface that a #NAIOption implementation should provide.
*/
typedef struct {
/*< private >*/
- GTypeInterface parent;
- NAIOptionInterfacePrivate *private;
+ GTypeInterface parent;
+ FMAIOptionInterfacePrivate *private;
/*< public >*/
/*
* get_version:
* @instance: the #NAIOption instance of the implementation.
*
* This method is supposed to let know to any caller which version of this
* interface the implementation provides. This may be useful when this
@@ -112,61 +112,61 @@ typedef struct {
*
* Since: 3.2
*/
- guint ( *get_version ) ( const NAIOption *instance );
+ guint ( *get_version ) ( const FMAIOption *instance );
/*
* get_id:
* @instance: the #NAIOption instance of the implementation.
*
* Returns: the string identifier of the option, as a newly allocated string
* which should be g_free() by the caller.
*
* Since: 3.2
*/
- gchar * ( *get_id ) ( const NAIOption *instance );
+ gchar * ( *get_id ) ( const FMAIOption *instance );
/*
* get_label:
* @instance: the #NAIOption instance of the implementation.
*
* Returns: the label of the option, as a newly allocated string
* which should be g_free() by the caller.
*
* Since: 3.2
*/
- gchar * ( *get_label ) ( const NAIOption *instance );
+ gchar * ( *get_label ) ( const FMAIOption *instance );
/*
* get_description:
* @instance: the #NAIOption instance of the implementation.
*
* Returns: the description of the option, as a newly allocated string
* which should be g_free() by the caller.
*
* Since: 3.2
*/
- gchar * ( *get_description )( const NAIOption *instance );
+ gchar * ( *get_description )( const FMAIOption *instance );
/*
* get_pixbuf:
* @instance: the #NAIOption instance of the implementation.
*
* Returns: the image assocated to the option, as a newly allocated string
* which should be g_object_unref() by the caller.
*
* Since: 3.2
*/
- GdkPixbuf * ( *get_pixbuf ) ( const NAIOption *instance );
+ GdkPixbuf * ( *get_pixbuf ) ( const FMAIOption *instance );
}
- NAIOptionInterface;
+ FMAIOptionInterface;
-GType na_ioption_get_type ( void );
+GType fma_ioption_get_type ( void );
-gchar *na_ioption_get_id ( const NAIOption *option );
-gchar *na_ioption_get_label ( const NAIOption *option );
-gchar *na_ioption_get_description( const NAIOption *option );
-GdkPixbuf *na_ioption_get_pixbuf ( const NAIOption *option );
+gchar *fma_ioption_get_id ( const FMAIOption *option );
+gchar *fma_ioption_get_label ( const FMAIOption *option );
+gchar *fma_ioption_get_description( const FMAIOption *option );
+GdkPixbuf *fma_ioption_get_pixbuf ( const FMAIOption *option );
G_END_DECLS
-#endif /* __CORE_NA_IOPTION_H__ */
+#endif /* __CORE_FMA_IOPTION_H__ */
@@ -27,22 +27,22 @@
*
- * The #NAIOption interface is to be implemented by #GObject -derived object which
- * are part of a #NAIOptionsList interface.
+ * The #FMAIOption interface is to be implemented by #GObject -derived object which
+ * are part of a #FMAIOptionsList interface.
*
* <refsect2>
@@ -27,22 +27,22 @@
* <title>Versions historic</title>
* <table>
- * <title>Historic of the versions of the #NAIOption interface</title>
+ * <title>Historic of the versions of the #FMAIOption interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
@@ -89,17 +89,17 @@ typedef struct _NAIOptionManageImportModeParms NAIOptionManageImportModeParms;
* @get_pixbuf: returns the image associated to the option.
*
- * This defines the interface that a #NAIOption implementation should provide.
+ * This defines the interface that a #FMAIOption implementation should provide.
*/
typedef struct {
@@ -89,17 +89,17 @@ typedef struct _NAIOptionManageImportModeParms NAIOptionManageImportModeParms;
/*
* get_version:
- * @instance: the #NAIOption instance of the implementation.
+ * @instance: the #FMAIOption instance of the implementation.
*
* This method is supposed to let know to any caller which version of this
@@ -112,61 +112,61 @@ typedef struct {
/*
* get_id:
- * @instance: the #NAIOption instance of the implementation.
+ * @instance: the #FMAIOption instance of the implementation.
*
* Returns: the string identifier of the option, as a newly allocated string
@@ -112,61 +112,61 @@ typedef struct {
/*
* get_label:
- * @instance: the #NAIOption instance of the implementation.
+ * @instance: the #FMAIOption instance of the implementation.
*
* Returns: the label of the option, as a newly allocated string
@@ -112,61 +112,61 @@ typedef struct {
/*
* get_description:
- * @instance: the #NAIOption instance of the implementation.
+ * @instance: the #FMAIOption instance of the implementation.
*
* Returns: the description of the option, as a newly allocated string
@@ -112,61 +112,61 @@ typedef struct {
/*
* get_pixbuf:
- * @instance: the #NAIOption instance of the implementation.
+ * @instance: the #FMAIOption instance of the implementation.
*
* Returns: the image assocated to the option, as a newly allocated string
diff --git a/src/core/na-ioptions-list.h b/src/core/fma-ioptions-list.h
similarity index 60%
rename from src/core/na-ioptions-list.h
rename to src/core/fma-ioptions-list.h
index 7288661..db149f8 100644
--- a/src/core/na-ioptions-list.h
+++ b/src/core/fma-ioptions-list.h
@@ -27,16 +27,16 @@
* ... and many others (see AUTHORS)
*/
-#ifndef __CORE_NA_IOPTIONS_LIST_H__
-#define __CORE_NA_IOPTIONS_LIST_H__
+#ifndef __CORE_FMA_IOPTIONS_LIST_H__
+#define __CORE_FMA_IOPTIONS_LIST_H__
/*
* SECTION: ioptions_list
- * @title: NAIOptionsList
+ * @title: FMAIOptionsList
* @short_description: The OptionsList Interface v 1
- * @include: core/na-ioptions-list.h
+ * @include: core/fma-ioptions-list.h
*
* The #NAIOptionsList interface is to be used when we have one option to choose
* among several. The interface takes care of:
* <itemizedlist>
* <listitem>
@@ -64,7 +64,7 @@
* </itemizedlist>
*
* In order this interface to work, each option has to be seen as a #GObject
* -derived object, which itself should implement the #NAIOption companion
* interface.
*
* Note that the instance which implements this interface is able to provide
@@ -73,12 +73,12 @@
*
* Instance initialization
*
* Rather that having to call a na_ioptions_list_instance_init() on each
* instance implementation, we prefer to check when entering in each public
* method for an 'initialized' flag both at the instance level and at the
* container level.
*
* Alternative might be be to have the na_ioptions_list_instance_init()
* initialization interface method, which itself connect to #BaseWindow
* signals. But this would not prevent of initializing for both managed
* containers...
@@ -89,7 +89,7 @@
* <refsect2>
* <title>Versions historic</title>
* <table>
* <title>Historic of the versions of the #NAIOptionsList interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
* <colspec colname="api-version" />
@@ -97,7 +97,7 @@
* <thead>
* <row>
* <entry>&prodname; version</entry>
- * <entry>#NAIOptionsList interface version</entry>
+ * <entry>#FMAIOptionsList interface version</entry>
* <entry></entry>
* </row>
* </thead>
@@ -115,40 +115,40 @@
#include <gtk/gtk.h>
-#include "na-ioption.h"
+#include "fma-ioption.h"
G_BEGIN_DECLS
-#define NA_TYPE_IOPTIONS_LIST ( na_ioptions_list_get_type())
-#define NA_IOPTIONS_LIST( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance,
NA_TYPE_IOPTIONS_LIST, NAIOptionsList ))
-#define NA_IS_IOPTIONS_LIST( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance,
NA_TYPE_IOPTIONS_LIST ))
-#define NA_IOPTIONS_LIST_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ),
NA_TYPE_IOPTIONS_LIST, NAIOptionsListInterface ))
+#define FMA_TYPE_IOPTIONS_LIST ( fma_ioptions_list_get_type())
+#define FMA_IOPTIONS_LIST( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance,
FMA_TYPE_IOPTIONS_LIST, FMAIOptionsList ))
+#define FMA_IS_IOPTIONS_LIST( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance,
FMA_TYPE_IOPTIONS_LIST ))
+#define FMA_IOPTIONS_LIST_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ),
FMA_TYPE_IOPTIONS_LIST, FMAIOptionsListInterface ))
-typedef struct _NAIOptionsList NAIOptionsList;
-typedef struct _NAIOptionsListInterfacePrivate NAIOptionsListInterfacePrivate;
-typedef struct _NAIOptionsListImportFromUriParms NAIOptionsListImportFromUriParms;
-typedef struct _NAIOptionsListManageImportModeParms NAIOptionsListManageImportModeParms;
+typedef struct _FMAIOptionsList FMAIOptionsList;
+typedef struct _FMAIOptionsListInterfacePrivate FMAIOptionsListInterfacePrivate;
+typedef struct _FMAIOptionsListImportFromUriParms FMAIOptionsListImportFromUriParms;
+typedef struct _FMAIOptionsListManageImportModeParms FMAIOptionsListManageImportModeParms;
/*
- * NAIOptionsListInterface:
+ * FMAIOptionsListInterface:
* @get_version: returns the version of this interface that the
* instance implements.
* @get_options: returns the list of #NAIOption.
* @free_options: releases the list of #NAIOption.
* @get_ask_option: returns the 'Ask me' #NAIOption.
* @free_ask_option: releases the 'Ask me' #NAIOption.
*
* This defines the interface that a #NAIOptionsList implementation should provide.
*/
typedef struct {
/*< private >*/
- GTypeInterface parent;
- NAIOptionsListInterfacePrivate *private;
+ GTypeInterface parent;
+ FMAIOptionsListInterfacePrivate *private;
/*< public >*/
/*
* get_version:
* @instance: the #NAIOptionsList instance of the implementation.
*
* This method is supposed to let know to any caller which version of this
* interface the implementation provides. This may be useful when this
@@ -161,26 +161,26 @@ typedef struct {
*
* Since: 3.2
*/
- guint ( *get_version ) ( const NAIOptionsList *instance );
+ guint ( *get_version ) ( const FMAIOptionsList *instance );
/*
* get_options:
* @instance: the #NAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
*
* This method may be called at more or less early stage of the build
* of the display, either rather early when displaying a radio button
* group, or later in the case of a tree view.
*
* Returns: a #GList list of #NAIOptions object instances.
*
* Since: 3.2
*/
- GList * ( *get_options ) ( const NAIOptionsList *instance, GtkWidget *container );
+ GList * ( *get_options ) ( const FMAIOptionsList *instance, GtkWidget *container );
/*
* free_options:
* @instance: the #NAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
* @options: a #GList of #NAIoption objects as returned by get_options() method.
*
@@ -193,25 +193,25 @@ typedef struct {
*
* Since: 3.2
*/
- void ( *free_options )( const NAIOptionsList *instance, GtkWidget *container, GList *options );
+ void ( *free_options )( const FMAIOptionsList *instance, GtkWidget *container, GList *options
);
/*
* get_ask_option:
* @instance: the #NAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
*
* Ask the implementation to provide a #NAIOption which defines the
* 'Ask me' option.
*
* Returns: a #NAIOption which defines the 'Ask me' option.
*
* Since: 3.2
*/
- NAIOption * ( *get_ask_option ) ( const NAIOptionsList *instance, GtkWidget *container );
+ FMAIOption * ( *get_ask_option ) ( const FMAIOptionsList *instance, GtkWidget *container );
/*
* free_ask_option:
* @instance: the #NAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
* @ask_option: the #NAIoption to be released.
*
@@ -223,20 +223,20 @@ typedef struct {
*
* Since: 3.2
*/
- void ( *free_ask_option )( const NAIOptionsList *instance, GtkWidget *container, NAIOption
*ask_option );
+ void ( *free_ask_option )( const FMAIOptionsList *instance, GtkWidget *container, FMAIOption
*ask_option );
}
- NAIOptionsListInterface;
+ FMAIOptionsListInterface;
-GType na_ioptions_list_get_type( void );
+GType fma_ioptions_list_get_type ( void );
-void na_ioptions_list_gtk_init ( const NAIOptionsList *instance, GtkWidget *container, gboolean
with_ask );
+void fma_ioptions_list_gtk_init ( const FMAIOptionsList *instance, GtkWidget *container, gboolean
with_ask );
-void na_ioptions_list_set_default ( const NAIOptionsList *instance, GtkWidget *container, const gchar
*default_id );
-void na_ioptions_list_set_editable ( const NAIOptionsList *instance, GtkWidget *container, gboolean
editable );
-void na_ioptions_list_set_sensitive( const NAIOptionsList *instance, GtkWidget *container, gboolean
sensitive );
+void fma_ioptions_list_set_default ( const FMAIOptionsList *instance, GtkWidget *container, const
gchar *default_id );
+void fma_ioptions_list_set_editable ( const FMAIOptionsList *instance, GtkWidget *container, gboolean
editable );
+void fma_ioptions_list_set_sensitive( const FMAIOptionsList *instance, GtkWidget *container, gboolean
sensitive );
-NAIOption *na_ioptions_list_get_selected ( const NAIOptionsList *instance, GtkWidget *container );
+FMAIOption *fma_ioptions_list_get_selected ( const FMAIOptionsList *instance, GtkWidget *container );
G_END_DECLS
-#endif /* __CORE_NA_IOPTIONS_LIST_H__ */
+#endif /* __CORE_FMA_IOPTIONS_LIST_H__ */
@@ -27,16 +27,16 @@
*
- * The #NAIOptionsList interface is to be used when we have one option to choose
+ * The #FMAIOptionsList interface is to be used when we have one option to choose
* among several. The interface takes care of:
* <itemizedlist>
@@ -64,7 +64,7 @@
*
* In order this interface to work, each option has to be seen as a #GObject
- * -derived object, which itself should implement the #NAIOption companion
+ * -derived object, which itself should implement the #FMAIOption companion
* interface.
*
@@ -73,12 +73,12 @@
* Instance initialization
*
- * Rather that having to call a na_ioptions_list_instance_init() on each
+ * Rather that having to call a fma_ioptions_list_instance_init() on each
* instance implementation, we prefer to check when entering in each public
* method for an 'initialized' flag both at the instance level and at the
@@ -73,12 +73,12 @@
* container level.
*
- * Alternative might be be to have the na_ioptions_list_instance_init()
+ * Alternative might be be to have the fma_ioptions_list_instance_init()
* initialization interface method, which itself connect to #BaseWindow
* signals. But this would not prevent of initializing for both managed
@@ -89,7 +89,7 @@
* <title>Versions historic</title>
* <table>
- * <title>Historic of the versions of the #NAIOptionsList interface</title>
+ * <title>Historic of the versions of the #FMAIOptionsList interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
@@ -115,40 +115,40 @@
* @get_version: returns the version of this interface that the
* instance implements.
- * @get_options: returns the list of #NAIOption.
- * @free_options: releases the list of #NAIOption.
- * @get_ask_option: returns the 'Ask me' #NAIOption.
- * @free_ask_option: releases the 'Ask me' #NAIOption.
+ * @get_options: returns the list of #FMAIOption.
+ * @free_options: releases the list of #FMAIOption.
+ * @get_ask_option: returns the 'Ask me' #FMAIOption.
+ * @free_ask_option: releases the 'Ask me' #FMAIOption.
*
@@ -115,40 +115,40 @@
*
- * This defines the interface that a #NAIOptionsList implementation should provide.
+ * This defines the interface that a #FMAIOptionsList implementation should provide.
*/
typedef struct {
@@ -115,40 +115,40 @@
/*
* get_version:
- * @instance: the #NAIOptionsList instance of the implementation.
+ * @instance: the #FMAIOptionsList instance of the implementation.
*
* This method is supposed to let know to any caller which version of this
@@ -161,26 +161,26 @@ typedef struct {
/*
* get_options:
- * @instance: the #NAIOptionsList instance of the implementation.
+ * @instance: the #FMAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
*
@@ -161,26 +161,26 @@ typedef struct {
* group, or later in the case of a tree view.
*
- * Returns: a #GList list of #NAIOptions object instances.
+ * Returns: a #GList list of #FMAIOptions object instances.
*
* Since: 3.2
@@ -161,26 +161,26 @@ typedef struct {
/*
* free_options:
- * @instance: the #NAIOptionsList instance of the implementation.
+ * @instance: the #FMAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
* @options: a #GList of #NAIoption objects as returned by get_options() method.
@@ -193,25 +193,25 @@ typedef struct {
/*
* get_ask_option:
- * @instance: the #NAIOptionsList instance of the implementation.
+ * @instance: the #FMAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
*
@@ -193,25 +193,25 @@ typedef struct {
* @container: the #GtkWidget which embeds the list of values.
*
- * Ask the implementation to provide a #NAIOption which defines the
+ * Ask the implementation to provide a #FMAIOption which defines the
* 'Ask me' option.
*
@@ -193,25 +193,25 @@ typedef struct {
* 'Ask me' option.
*
- * Returns: a #NAIOption which defines the 'Ask me' option.
+ * Returns: a #FMAIOption which defines the 'Ask me' option.
*
* Since: 3.2
@@ -193,25 +193,25 @@ typedef struct {
/*
* free_ask_option:
- * @instance: the #NAIOptionsList instance of the implementation.
+ * @instance: the #FMAIOptionsList instance of the implementation.
* @container: the #GtkWidget which embeds the list of values.
* @ask_option: the #NAIoption to be released.